@@ -6,30 +6,39 @@ altgraph is a fork of `graphlib <http://pygraphlib.sourceforge.net>`_ tailored
 to use newer Python 2.3+ features, including additional support used by the
 py2app suite (modulegraph and macholib, specifically).
 
-altgraph is a python based graph (network) representation and manipulation package.
-It has started out as an extension to the `graph_lib module <http://www.ece.arizona.edu/~denny/python_nest/graph_lib_1.0.1.html>`_
+altgraph is a python based graph (network) representation and manipulation
+package.  It has started out as an extension to the
+`graph_lib module
+<http://www.ece.arizona.edu/~denny/python_nest/graph_lib_1.0.1.html>`_
 written by Nathan Denny it has been significantly optimized and expanded.
 
-The :class:`altgraph.Graph.Graph` class is loosely modeled after the `LEDA <http://www.algorithmic-solutions.com/enleda.htm>`_ 
-(Library of Efficient Datatypes)  representation. The library
+The :class:`altgraph.Graph.Graph` class is loosely modeled after the
+`LEDA <http://www.algorithmic-solutions.com/enleda.htm>`_
+(Library of Efficient Datatypes) representation. The library
 includes methods for constructing graphs, BFS and DFS traversals,
-topological sort, finding connected components, shortest paths as well as a number
-graph statistics functions. The library can also visualize graphs
+topological sort, finding connected components, shortest paths as well as a
+number graph statistics functions. The library can also visualize graphs
 via `graphviz <http://www.research.att.com/sw/tools/graphviz/>`_.
 
 The package contains the following modules:
 
-    -  the :py:mod:`altgraph.Graph` module contains the :class:`~altgraph.Graph.Graph` class that stores the graph data
+    -  the :py:mod:`altgraph.Graph` module contains the
+       :class:`~altgraph.Graph.Graph` class that stores the graph data
 
-    -  the :py:mod:`altgraph.GraphAlgo` module implements graph algorithms operating on graphs (:py:class:`~altgraph.Graph.Graph`} instances)
+    -  the :py:mod:`altgraph.GraphAlgo` module implements graph algorithms
+       operating on graphs (:py:class:`~altgraph.Graph.Graph`} instances)
 
-    -  the :py:mod:`altgraph.GraphStat` module contains functions for computing statistical measures on graphs
+    -  the :py:mod:`altgraph.GraphStat` module contains functions for
+       computing statistical measures on graphs
 
-    -  the :py:mod:`altgraph.GraphUtil` module contains functions for generating, reading and saving graphs
+    -  the :py:mod:`altgraph.GraphUtil` module contains functions for
+       generating, reading and saving graphs
 
-    -  the :py:mod:`altgraph.Dot` module  contains functions for displaying graphs via `graphviz <http://www.research.att.com/sw/tools/graphviz/>`_
+    -  the :py:mod:`altgraph.Dot` module  contains functions for displaying
+       graphs via `graphviz <http://www.research.att.com/sw/tools/graphviz/>`_
 
-    -  the :py:mod:`altgraph.ObjectGraph` module implements a graph of objects with a unique identifier
+    -  the :py:mod:`altgraph.ObjectGraph` module implements a graph of
+       objects with a unique identifier
 
 Installation
 ------------
@@ -50,8 +59,8 @@ To verify that the code works run the test suite::
 Example usage
 -------------
 
-Lets assume that we want to analyze the graph below (links to the full picture) GRAPH_IMG.
-Our script then might look the following way::
+Lets assume that we want to analyze the graph below (links to the full picture)
+GRAPH_IMG.  Our script then might look the following way::
 
     from altgraph import Graph, GraphAlgo, Dot
 
@@ -110,26 +119,29 @@ To display the graph we can use the GraphViz backend::
 
   Copyright (c) 2004 Istvan Albert unless otherwise noted.
 
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this software
-  and associated documentation files (the "Software"), to deal in the Software without restriction,
-  including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
-  and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do
-  so.
+  Permission is hereby granted, free of charge, to any person obtaining a copy
+  of this software and associated documentation files (the "Software"), to
+  deal in the Software without restriction, including without limitation the
+  rights to use, copy, modify, merge, publish, distribute, sublicense,
+  and/or sell copies of the Software, and to permit persons to whom the
+  Software is furnished to do so.
 
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-  PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
-  FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
-  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-  THE SOFTWARE.
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+  IN THE SOFTWARE.
   @requires: Python 2.3 or higher
 
   @newfield contributor: Contributors:
   @contributor: U{Reka Albert <http://www.phys.psu.edu/~ralbert/>}
 
 '''
+import pkg_resources
+__version__ = pkg_resources.require('altgraph')[0].version
 
-__version__ = '0.7.0'
 
 class GraphError(ValueError):
     pass
